#
# spec file for package calligra-plan
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           calligra-plan
Version:        3.3.0
Release:        2.8
Summary:        Project Management Application
License:        GPL-2.0-only AND GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Office/Suite
URL:            https://www.calligra.org/
Source0:        https://download.kde.org/stable/calligra/%{version}/calligraplan-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  perl-base
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KChart) >= 2.8.0
BuildRequires:  cmake(KF5Activities)
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5GuiAddons)
BuildRequires:  cmake(KF5Holidays)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5Init)
BuildRequires:  cmake(KF5ItemViews)
BuildRequires:  cmake(KF5JobWidgets)
BuildRequires:  cmake(KF5KHtml)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5Wallet)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(KGantt) >= 2.8.0
BuildRequires:  cmake(Qca-qt5)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(Qt5Xml)
# For mimetype definitions
Requires:       kcoreaddons
# some icons were part of the main calligra package before 3.1.0
Conflicts:      calligra < 3.1.0
Obsoletes:      calligra5-plan

%description
Plan is the project management application of the Calligra Suite.

%lang_package

%prep
%autosetup -p1 -n calligraplan-%{version}

%build
%cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
%cmake_build

%install
%kf5_makeinstall -C build
%kf5_find_lang %{name}
%kf5_find_htmldocs

%suse_update_desktop_file -r org.kde.calligraplan       Qt KDE Office ProjectManagement
%suse_update_desktop_file -r org.kde.calligraplanwork   Qt KDE Office ProjectManagement

# not needed
rm %{buildroot}/%{_kf5_libdir}/libplan*.so

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING*
%doc CHANGELOG
%config %{_kf5_configdir}/calligra*rc
%{_kf5_applicationsdir}/org.kde.calligraplan.desktop
%{_kf5_applicationsdir}/org.kde.calligraplanwork.desktop
%{_kf5_appstreamdir}/org.kde.calligraplan.appdata.xml
%{_kf5_bindir}/calligraplan
%{_kf5_bindir}/calligraplanwork
%dir %{_kf5_configkcfgdir}
%{_kf5_configkcfgdir}/calligraplan*.kcfg
%doc %lang(en) %{_kf5_htmldir}/en
%{_kf5_iconsdir}/hicolor/
%{_kf5_kxmlguidir}/calligraplan/
%{_kf5_kxmlguidir}/calligraplanwork/
%{_kf5_libdir}/libkdeinit5_calligraplan*.so
%{_kf5_libdir}/libplan*.so.*
%{_kf5_plugindir}/calligraplan/
%{_kf5_plugindir}/calligraplanworkpart.so
%{_kf5_sharedir}/calligraplan/
%{_kf5_sharedir}/calligraplanwork/

%files lang -f %{name}.lang

%changelog
* Tue Dec 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add dependency on kcoreaddons (boo#1193959)
* Thu Jan 28 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 3.3.0
  * Allow to print a selectable time range
  * Fit printout to page height
  * Fit printout to a single page
  * Print the chart on multiple pages
  * Uses a color palette suitable for printing on white paper
  * Use the mouse or mouse wheel to zoom the datetime scale
- Drop 0001-Fix-build-with-Qt-5.15.patch, merged upstream
* Thu Jun  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to build with Qt 5.15:
  * 0001-Fix-build-with-Qt-5.15.patch
* Fri Dec 13 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 3.2.2
- Bugs fixed:
  * Default calendar not set when creating new project (kde#415041)
  * Remaining effort not merged if nothing else has changed
    (kde#414783)
  * Stray () parentheses displayed in schedule selector
    (kde#414781)
  * Can't add progress finish time in the past (kde#414661)
* Mon Dec  2 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 3.2.1
- Bugs fixed:
  * View specific dockers not shown in Settings->Dockers
    (kde#414164)
  * Crash during save (kde#414162)
  * Actual effort editable in list view (kde#414253)
  * Task modules settings not undoable (kde#414257)
  * Task modules parameter listed multiple times (kde#414204)
  * Task modules directory duplicated in Project Settings
    (kde#414133)
  * Entries in the workpackage merge dialog shall not be editable
* Thu Nov 14 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 3.2.0
- General:
  * Add drag/drop and copy/paste using text/html and text/plain
    mimetypes
  * Landscape printing/export was not possible (kde#412063)
  * Add project templates
  * calligraplan didn't load translations from calligraplanlibs.mo
    (kde#412325)
  * Add hyper link handling to description editor
  * Use project name in recent projects list instead of file name
  * Collect project settings into separate Project menu
  * Add view options to the View menu
  * Open description from treeviews on doubleclick
  * Improve edit/view Documents
  * Add documents to project dialog
  * Add dialog to reload assignments of shared resources
  * Always save currency in case project is opened in a different
    locale
  * Fix crash when creating new project with separate holiday
    calendar
- Help and Documentation:
  * Help is provided using What's this (Shift-F1)
  * Documentation has been improved (still WIP)
- Task editor:
  * Add copy/paste of tasks, also possible using drag/drop
  * Allow to indent/unindent multiple tasks (kde#412749)
  * Add option to specify dependencies manually (kde#412341)
  * Allow for entering estimates in minutes (kde#412134)
  * Add priority feature, use value for levelling/scheduling
    (kde#309038)
  * Allow to drag/drop non-baselined tasks on a baselined project
  * Fix bug "Unable to delete tasks" (kde#406127)
  * TaskModules: Improve task modules handling
- Dependency Editor:
  * Fix bug in Finish-Finish dependency check in dependency editor
    (kde#401511)
- Scheduling:
  * Add automatic scheduling mode
  * Use task priority (kde#309038)
  * Handle removed task/resource during scheduling
  * Fix crash on close when scheduling is running
- Ganttview:
  * Enable editing of completion
  * Extend the "View" menu (Zoom, Scale, Timeformat, Year Format,
    Grid) in Gantt view mode (kde#284361)
  * Add timeline
  * Add contextmenu -> Show Unscheduled Tasks
  * Trigger an update of the chart when project start may have
    changed
  * Enable context menu from gantt chart
- Performance charts:
  * Coordinate rubberband selection, drag&drop and context menus
- Reports:
  * Improve report templates and generation
  * Add documentation
- Filters:
  * ICalExport filter: Enable user to choose what to export
  * Add import filter for Gnome Planner project files
- Workpackage handling:
  * Improve workpackage handling
  * Fix bug in merging workpackage used effort (kde#287563)
  * Fix "Can not edit a progress entry of a task" (kde#342574),
    improve progress dialog in general
- PlanWork:
  * Enable opening documents from gantt view
  * Enable sorting gantt view
  * Fix sorting by dattime
  * Mark finished tasks with a checkmark
- Drop patches merged upstream:
  * Fix-build-with-Qt-511.patch
  * Fix-compilation-after-recent-KCalCore-API-changes.patch
  * Fix-build-with-Qt-5_13.patch
* Mon Aug 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add Fix-build-with-Qt-5_13.patch
- Drop 0001-Plan-fix-build-with-Qt-5.6.patch. Fixed upstream
- Refresh Fix-build-with-Qt-511.patch
- Refresh Fix-compilation-after-recent-KCalCore-API-changes.patch
* Sat Jul 27 2019 wbauer@tmo.at
- Add Fix-compilation-after-recent-KCalCore-API-changes.patch to
  fix build with kcalcore 19.08
* Sun Jun  3 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch.
- Run spec-cleaner.
* Wed Mar 28 2018 wbauer@tmo.at
- Drop _constraints, this was taken over from calligra but
  shouldn't be necessary to build plan alone...
* Thu Mar 22 2018 wbauer@tmo.at
- Conflict with calligra < 3.1.0, some icons were part of the main
  calligra package previously
* Tue Mar 20 2018 wbauer@tmo.at
- Add 0001-Plan-fix-build-with-Qt-5.6.patch to fix build on Leap 42
* Sat Jan 27 2018 wbauer@tmo.at
- Initial package of version 3.1.0, plan is released separately
  from calligra now
- Changes since 3.0.1 (where it was still part of calligra):
  * Add dialog to be able to edit multiple tasks at once
    (kde#310937)
  * Provide expand all/collapse all in context menu (kde#313606)
    Expands/collapses selected item(s) and all children
    Retains the treeviews expanded rows across operations
  * Printing: Make changes to page layout persistent (kde#385084)
  * Open Document Text format report generator added
    Adds the abillity to generate reports in odt format directly.
    Reports can be viewed using an odt viewer like Calligra Words
    or LibreOffice Writer
    Report templates are also in odt format and can be designed
    using e.g Words or Writer
  * Add support for sharing resources in multiple projects
  * Improved context help and documentation
  * Add support for automatic holidays generation
  * Calendar view: Handle context menus with no calendar
  * Replace the file centric startup page with page more suitable
    for projects
  * Add editing and reloading of task modules.
  * Gantt view: Fix possible crash when deleting gantt view with
    large projects
  * Gantt view: Fix issue with task dependencies not cleared in
    certain situations
  * Fix undo/redo issue with modifying project target times
  * Fix potential crash in Cost Breakdown View
  * Fix potential crash when creating new project from current
    project
  * Fix performance issue in chart view
  Note:
  * Support for scripting is discontinued
  * Reports using KReport is not supported in this release
